%define    debug_package %{nil}

Summary:       The Prometheus monitoring system and time series database
Name:          prometheus
Version:       2.42.0
Release:       5%{?dist}
License:       Apache-2.0
URL:           https://prometheus.io
Source0:       https://github.com/prometheus/prometheus/archive/refs/tags/v%{version}.tar.gz
Source1:       vendor.tar.gz
Source2:       prometheus.service
Source3:       prometheus.yml

# unzip Source0 and run 'make build' in it
# then run 'rm -rf web/ui/react-app'
# and run 'tar -czvf ../web-ui-version.tar.gz web/ui'
# and run 'mv npm_licenses.tar.bz2 ..'
Source4:       web-ui-%{version}.tar.gz
Source5:       npm_licenses.tar.bz2

Patch3001:     0001-Do-not-force-the-pure-Go-name-resolver.patch
Patch3002:     0002-Default-settings.patch

BuildRequires: fdupes glibc-devel promu golang go-rpm-macros systemd-rpm-macros
Recommends:    firewalld-prometheus-config
Requires(pre): shadow-utils
%{?systemd_requires}
ExcludeArch: loongarch64

%description
Prometheus's main features are:
 - a multi-dimensional data model (time series identified by metric name and key/value pairs)
 - a flexible query language to leverage this dimensionality
 - no reliance on distributed storage; single server nodes are autonomous
 - time series collection happens via a pull model over HTTP
 - pushing time series is supported via an intermediary gateway
 - targets are discovered via service discovery or static configuration
 - multiple modes of graphing and dashboarding support

%prep
%setup -q -a1 -n prometheus-%{version}
%autosetup -D -a4 -p1 -n prometheus-%{version}

%build
GOPATH=%{_builddir}/go promu build -v

%install
install -D -m0755 %{_builddir}/prometheus-%{version}/prometheus %{buildroot}%{_bindir}/prometheus
install -D -m0755 %{_builddir}/prometheus-%{version}/promtool %{buildroot}%{_bindir}/promtool
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/prometheus.service
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/prometheus/prometheus.yml

install -d -m 0755 %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcprometheus

install -m 0755 -d %{buildroot}%{_datarootdir}/prometheus
cp -fr console_libraries/ consoles/ %{buildroot}%{_datarootdir}/prometheus

install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus
install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus/data
install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus/metrics
install -D -m0644 %{SOURCE5} %{buildroot}/%{_defaultlicensedir}/%{name}/npm_licenses.tar.bz2

%pre
getent group prometheus >/dev/null || groupadd -r prometheus
getent passwd prometheus >/dev/null || \
  useradd -r -g prometheus -d %{_sharedstatedir}/prometheus -s /sbin/nologin \
          -c "Prometheus services" prometheus
exit 0

%post
%systemd_post prometheus.service

%preun
%systemd_preun prometheus.service

%postun
%systemd_postun prometheus.service

%files
%defattr(-,root,root,-)
%license LICENSE
%license %{_defaultlicensedir}/%{name}
%doc README.md
%{_unitdir}/prometheus.service
%{_bindir}/prometheus
%{_bindir}/promtool
%{_sbindir}/rcprometheus
%{_datarootdir}/prometheus
%dir %attr(0700,prometheus,prometheus) %{_sharedstatedir}/prometheus
%dir %attr(0700,prometheus,prometheus) %{_sharedstatedir}/prometheus/data
%dir %attr(0700,prometheus,prometheus) %{_sharedstatedir}/prometheus/metrics
%dir %{_sysconfdir}/prometheus
%config(noreplace) %{_sysconfdir}/prometheus/prometheus.yml

%changelog
* Thu Jul 25 2024 Pengda Dou <doupengda@loongson.cn> - 2.42.0-5
- [Type] other
- [DESC] add loongarch64 to ExcludeArch

* Mon Jan 29 2024 jackeyji <jackeyji@tencent.com> - 2.42.0-4
- add web/ui because it need generate online in promu-0.15.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.42.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.42.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 6 2023 Shuo Wang <abushwang@tencent.com> - 2.42.0-1
- initial build

